{
    "$graph": [
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "registry.gitlab.com/uc-cdis/genomel-exome-variant-detection/genomel_variant_calling:2.0"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#gatk3_selectvariants.cwl/input_vcf"
                },
                {
                    "type": "string",
                    "id": "#gatk3_selectvariants.cwl/job_uuid"
                },
                {
                    "type": "string",
                    "id": "#gatk3_selectvariants.cwl/output_prefix"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#gatk3_selectvariants.cwl/reference"
                }
            ],
            "baseCommand": [],
            "arguments": [
                {
                    "position": 0,
                    "shellQuote": false,
                    "valueFrom": "/usr/bin/time -f \"{\\\\\"real_time\\\\\": \\\\\"%E\\\\\", \\\\\"user_time\\\\\": %U, \\\\\"system_time\\\\\": %S, \\\\\"wall_clock\\\\\": %e, \\\\\"maximum_resident_set_size\\\\\": %M, \\\\\"average_total_mem\\\\\": %K, \\\\\"percent_of_cpu\\\\\": \\\\\"%P\\\\\"}\" -o $(inputs.job_uuid + '.gatk3_selectvariants.time.json') java -Xmx100G -XX:ParallelGCThreads=30 -jar /opt/GenomeAnalysisTK.jar -T SelectVariants --variant $(inputs.input_vcf.path) -R $(inputs.reference.path) -o $(inputs.output_prefix + '.filtered.site_only.vcf.gz') -select \"QUAL > 20.0\" -ef -env"
                }
            ],
            "id": "#gatk3_selectvariants.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_prefix + '.filtered.site_only.vcf.gz')"
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#gatk3_selectvariants.cwl/output_vcf"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.job_uuid + '.gatk3_selectvariants.time.json')"
                    },
                    "id": "#gatk3_selectvariants.cwl/time_metrics"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "registry.gitlab.com/uc-cdis/genomel-exome-variant-detection/gatk4_0_11:2.0"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "gvcf_path.list",
                            "entry": "${\n  var paths = [];\n  for (var i = 0; i < inputs.gvcf_files.length; i++){\n    if (inputs.gvcf_files[i][\"nameext\"] == \".gz\"){\n      paths.push(inputs.gvcf_files[i][\"path\"])\n      }\n    }\n  return paths.join(\"\\n\")\n  }\n"
                        }
                    ]
                },
                {
                    "class": "ResourceRequirement",
                    "coresMin": 30
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#genomel_gatk4_cohort_genotyping.cwl/bed_file"
                },
                {
                    "type": "boolean",
                    "default": false,
                    "inputBinding": {
                        "position": 99,
                        "prefix": "-e"
                    },
                    "id": "#genomel_gatk4_cohort_genotyping.cwl/cromwell_engine"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#genomel_gatk4_cohort_genotyping.cwl/gvcf_files"
                },
                {
                    "type": "string",
                    "id": "#genomel_gatk4_cohort_genotyping.cwl/job_uuid"
                },
                {
                    "type": "int",
                    "id": "#genomel_gatk4_cohort_genotyping.cwl/number_of_chunks"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#genomel_gatk4_cohort_genotyping.cwl/reference"
                },
                {
                    "type": "int",
                    "id": "#genomel_gatk4_cohort_genotyping.cwl/thread_count"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.job_uuid + '.genomel_pdc_gatk4_cohort_genotyping.time.json')"
                    },
                    "id": "#genomel_gatk4_cohort_genotyping.cwl/time_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*.vcf.gz"
                    },
                    "id": "#genomel_gatk4_cohort_genotyping.cwl/vcf_list"
                }
            ],
            "baseCommand": [],
            "arguments": [
                {
                    "position": 0,
                    "shellQuote": false,
                    "valueFrom": "sed 's/\\\\\\\\n/\\\\n/g' gvcf_path.list > fixed_gvcf_path.list\n/usr/bin/time -f \"{\\\\\"real_time\\\\\": \\\\\"%E\\\\\", \\\\\"user_time\\\\\": %U, \\\\\"system_time\\\\\": %S, \\\\\"wall_clock\\\\\": %e, \\\\\"maximum_resident_set_size\\\\\": %M, \\\\\"average_total_mem\\\\\": %K, \\\\\"percent_of_cpu\\\\\": \\\\\"%P\\\\\"}\" -o $(inputs.job_uuid + '.genomel_pdc_gatk4_cohort_genotyping.time.json') python /opt/genomel_pdc_gatk4_cohort_genotyping.py --gvcf_path fixed_gvcf_path.list -j $(inputs.job_uuid) -f $(inputs.reference.path) -L $(inputs.bed_file.path) -n $(inputs.thread_count) -c $(inputs.number_of_chunks)"
                }
            ],
            "id": "#genomel_gatk4_cohort_genotyping.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "registry.gitlab.com/uc-cdis/genomel-exome-variant-detection/genomel_variant_calling:1.0"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#picard_sortvcf.cwl/job_uuid"
                },
                {
                    "type": "string",
                    "id": "#picard_sortvcf.cwl/output_prefix"
                },
                {
                    "type": "File",
                    "id": "#picard_sortvcf.cwl/reference_dict"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "prefix": "I=",
                            "separate": false
                        }
                    },
                    "inputBinding": {
                        "position": 99
                    },
                    "id": "#picard_sortvcf.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.job_uuid + '.' + inputs.output_prefix + '.vcf.gz')"
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#picard_sortvcf.cwl/sorted_vcf"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.job_uuid + '.picard_sortvcf.time.json')"
                    },
                    "id": "#picard_sortvcf.cwl/time_metrics"
                }
            ],
            "baseCommand": [],
            "arguments": [
                {
                    "position": 0,
                    "shellQuote": false,
                    "valueFrom": "/usr/bin/time -f \"{\\\\\"real_time\\\\\": \\\\\"%E\\\\\", \\\\\"user_time\\\\\": %U, \\\\\"system_time\\\\\": %S, \\\\\"wall_clock\\\\\": %e, \\\\\"maximum_resident_set_size\\\\\": %M, \\\\\"average_total_mem\\\\\": %K, \\\\\"percent_of_cpu\\\\\": \\\\\"%P\\\\\"}\" -o $(inputs.job_uuid + '.picard_sortvcf.time.json') java -Xmx100G -XX:ParallelGCThreads=30 -jar /opt/picard.jar SortVcf CREATE_INDEX=true OUTPUT=$(inputs.job_uuid + '.' + inputs.output_prefix + '.vcf.gz') SEQUENCE_DICTIONARY=$(inputs.reference_dict.path)"
                }
            ],
            "id": "#picard_sortvcf.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/bed_file"
                },
                {
                    "type": "boolean",
                    "id": "#main/cromwell_engine"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/gvcf_files"
                },
                {
                    "type": "string",
                    "id": "#main/job_uuid"
                },
                {
                    "type": "int",
                    "id": "#main/number_of_chunks"
                },
                {
                    "type": "string",
                    "id": "#main/output_prefix"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#main/reference"
                },
                {
                    "type": "int",
                    "id": "#main/thread_count"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/gatk3_selectvariants/output_vcf",
                    "id": "#main/gatk4_cohort_genotyping_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/genomel_pdc_gatk4_cohort_genotyping/time_metrics",
                    "id": "#main/time_metrics_from_gatk4_cohort_genotyping"
                },
                {
                    "type": "File",
                    "outputSource": "#main/picard_sortvcf/time_metrics",
                    "id": "#main/time_metrics_from_picard_sortvcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/gatk3_selectvariants/time_metrics",
                    "id": "#main/time_metrics_from_selectvariants"
                }
            ],
            "steps": [
                {
                    "run": "#gatk3_selectvariants.cwl",
                    "in": [
                        {
                            "source": "#main/picard_sortvcf/sorted_vcf",
                            "id": "#main/gatk3_selectvariants/input_vcf"
                        },
                        {
                            "source": "#main/job_uuid",
                            "id": "#main/gatk3_selectvariants/job_uuid"
                        },
                        {
                            "source": [
                                "#main/job_uuid",
                                "#main/output_prefix"
                            ],
                            "valueFrom": "$(self[0] + '.' + self[1] + '.gatk4')",
                            "id": "#main/gatk3_selectvariants/output_prefix"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/gatk3_selectvariants/reference"
                        }
                    ],
                    "out": [
                        "#main/gatk3_selectvariants/output_vcf",
                        "#main/gatk3_selectvariants/time_metrics"
                    ],
                    "id": "#main/gatk3_selectvariants"
                },
                {
                    "run": "#genomel_gatk4_cohort_genotyping.cwl",
                    "in": [
                        {
                            "source": "#main/bed_file",
                            "id": "#main/genomel_pdc_gatk4_cohort_genotyping/bed_file"
                        },
                        {
                            "source": "#main/cromwell_engine",
                            "id": "#main/genomel_pdc_gatk4_cohort_genotyping/cromwell_engine"
                        },
                        {
                            "source": "#main/gvcf_files",
                            "id": "#main/genomel_pdc_gatk4_cohort_genotyping/gvcf_files"
                        },
                        {
                            "source": "#main/job_uuid",
                            "id": "#main/genomel_pdc_gatk4_cohort_genotyping/job_uuid"
                        },
                        {
                            "source": "#main/number_of_chunks",
                            "id": "#main/genomel_pdc_gatk4_cohort_genotyping/number_of_chunks"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/genomel_pdc_gatk4_cohort_genotyping/reference"
                        },
                        {
                            "source": "#main/thread_count",
                            "id": "#main/genomel_pdc_gatk4_cohort_genotyping/thread_count"
                        }
                    ],
                    "out": [
                        "#main/genomel_pdc_gatk4_cohort_genotyping/vcf_list",
                        "#main/genomel_pdc_gatk4_cohort_genotyping/time_metrics"
                    ],
                    "id": "#main/genomel_pdc_gatk4_cohort_genotyping"
                },
                {
                    "run": "#picard_sortvcf.cwl",
                    "in": [
                        {
                            "source": "#main/job_uuid",
                            "id": "#main/picard_sortvcf/job_uuid"
                        },
                        {
                            "source": "#main/output_prefix",
                            "valueFrom": "$(self + '.srt')",
                            "id": "#main/picard_sortvcf/output_prefix"
                        },
                        {
                            "source": "#main/reference",
                            "valueFrom": "$(self.secondaryFiles[1])",
                            "id": "#main/picard_sortvcf/reference_dict"
                        },
                        {
                            "source": "#main/genomel_pdc_gatk4_cohort_genotyping/vcf_list",
                            "id": "#main/picard_sortvcf/vcf"
                        }
                    ],
                    "out": [
                        "#main/picard_sortvcf/sorted_vcf",
                        "#main/picard_sortvcf/time_metrics"
                    ],
                    "id": "#main/picard_sortvcf"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
